package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcWb;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWlaqzcqy;
import com.ruoyi.tcZz.service.ITcWlaqzcqyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 网络安全支持单位Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "网络安全支持单位")
@RequestMapping("/tcZz/networkEcology/wlaqzcqy")
public class TcWlaqzcqyController extends BaseController
{
    @Autowired
    private ITcWlaqzcqyService tcWlaqzcqyService;

    /**
     * 查询网络安全支持单位列表
     */
    @ApiOperation(value = "查询网络安全支持单位列表",response = TcWlaqzcqy.class)
    @GetMapping("/list")
    public TableDataInfo list(TcWlaqzcqy tcWlaqzcqy)
    {
        startPage();
        List<TcWlaqzcqy> list = tcWlaqzcqyService.selectTcWlaqzcqyList(tcWlaqzcqy);
        return getDataTable(list);
    }

    /**
     * 导出网络安全支持单位列表
     */
    @ApiOperation(value = "导出网络安全支持单位列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWlaqzcqy tcWlaqzcqy)
    {
        List<TcWlaqzcqy> list = tcWlaqzcqyService.selectTcWlaqzcqyList(tcWlaqzcqy);
        ExcelUtil<TcWlaqzcqy> util = new ExcelUtil<TcWlaqzcqy>(TcWlaqzcqy.class);
        util.exportExcel(response, list, "网络安全支持单位数据");
    }

    /**
     * 获取网络安全支持单位详细信息
     */
    @ApiOperation(value = "获取网络安全支持单位详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcWlaqzcqyService.selectTcWlaqzcqyById(id));
    }

    /**
     * 新增网络安全支持单位
     */
    @ApiOperation(value = "新增网络安全支持单位")
    @PostMapping
    public AjaxResult add(@RequestBody TcWlaqzcqy tcWlaqzcqy)
    {
        return toAjax(tcWlaqzcqyService.insertTcWlaqzcqy(tcWlaqzcqy));
    }

    /**
     * 修改网络安全支持单位
     */
    @ApiOperation(value = "修改网络安全支持单位")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWlaqzcqy tcWlaqzcqy)
    {
        return toAjax(tcWlaqzcqyService.updateTcWlaqzcqy(tcWlaqzcqy));
    }

    /**
     * 删除网络安全支持单位
     */
    @ApiOperation(value = "删除网络安全支持单位")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcWlaqzcqyService.deleteTcWlaqzcqyByIds(ids));
    }



    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWlaqzcqy> util = new ExcelUtil<TcWlaqzcqy>(TcWlaqzcqy.class);
        List<TcWlaqzcqy> tcWlaqzcqyList = util.importExcel(file.getInputStream());
        tcWlaqzcqyService.importUser(tcWlaqzcqyList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWlaqzcqyService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWlaqzcqy> util = new ExcelUtil<TcWlaqzcqy>(TcWlaqzcqy.class);
        util.importTemplateExcel(response, " 网络安全支持单位");
    }
}
